summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorLinus Färnstrand <linus@mullvad.net>2017-11-23 09:53:52 +0100
committerAndrej Mihajlov <and@mullvad.net>2017-11-23 12:41:13 +0100
commitd81d992aac034bc2d726b55951f0c654b2b6c470 (patch)
tree8123d7cef16f9249386bbea555b53d1c34d7c76a
parente7782654f1ffc7268dd6295096bc9c7857cd3ec9 (diff)
downloadmullvadvpn-d81d992aac034bc2d726b55951f0c654b2b6c470.tar.xz
mullvadvpn-d81d992aac034bc2d726b55951f0c654b2b6c470.zip
Change default udp port to 1301
-rw-r--r--app/containers/AdvancedSettingsPage.js4
-rw-r--r--app/lib/backend.js2
-rw-r--r--test/mocks/ipc.js2
3 files changed, 4 insertions, 4 deletions
diff --git a/app/lib/backend.js b/app/lib/backend.js
index 5f19354753..db3d949ffa 100644
--- a/app/lib/backend.js
+++ b/app/lib/backend.js
@@ -271,7 +271,7 @@ export class Backend {
openvpn: {
// TODO: protocol and port are temporarily hardcoded
protocol: 'udp',
- port: 1300,
+ port: 1301,
}
},
},
diff --git a/test/mocks/ipc.js b/test/mocks/ipc.js
index 5b3b7ea1ac..59655c03ab 100644
--- a/test/mocks/ipc.js
+++ b/test/mocks/ipc.js
@@ -35,7 +35,7 @@ export function newMockIpc() {
host: 'www.example.com',
tunnel: {
openvpn: {
- port: 1300,
+ port: 1301,
protocol: 'udp',
}
}
diff --git a/app/containers/AdvancedSettingsPage.js b/app/containers/AdvancedSettingsPage.js
index fd83406c25..74e59ec60a 100644
--- a/app/containers/AdvancedSettingsPage.js
+++ b/app/containers/AdvancedSettingsPage.js
@@ -20,9 +20,9 @@ const mapDispatchToProps = (dispatch, props) => {
onClose: () => dispatch(push('/settings')),
onUpdateConstraints: (host, protocol, port) => {
// TODO: udp and 1300 are automatic because we cannot pass `any` when using custom tunnel
const protocolConstraint = protocol === 'Automatic' ? 'udp' : protocol.toLowerCase();
- const portConstraint = port === 'Automatic' ? (protocolConstraint === 'tcp' ? 443 : 1300) : port;
+ const portConstraint = port === 'Automatic' ? (protocolConstraint === 'tcp' ? 443 : 1301) : port;
const update = {
custom_tunnel_endpoint: {
host: host,
@@ -20,9 +20,9 @@ const mapDispatchToProps = (dispatch, props) => {
onClose: () => dispatch(push('/settings')),
onUpdateConstraints: (host, protocol, port) => {
- // TODO: udp and 1300 are automatic because we cannot pass `any` when using custom tunnel
+ // TODO: udp and 1301 are automatic because we cannot pass `any` when using custom tunnel
const protocolConstraint = protocol === 'Automatic' ? 'udp' : protocol.toLowerCase();